#
# spec file for package python-jmespath
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define baseName jmespath

Name:           python-jmespath
Version:        0.9.2
Release:        7.1
Summary:        Extract elements from JSON document
License:        MIT
Group:          Development/Languages/Python
Url:            https://github.com/boto/jmespath
Source0:        https://pypi.python.org/packages/source/j/%{baseName}/%{baseName}-%{version}.tar.gz
Requires:       python
Requires:       python-ply >= 3.4
BuildRequires:  python
BuildRequires:  python-devel
BuildRequires:  python-ply
BuildRequires:  python-setuptools
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif

%description
JMESPath (pronounced "jaymz path") allows you to declaratively specify how
to extract elements from a JSON document.

For example, given this document:

{"foo": {"bar": "baz"}}

The jmespath expression foo.bar will return "baz".

JMESPath also supports:

Referencing elements in a list. Given the data:

{"foo": {"bar": ["one", "two"]}}

The expression: foo.bar[0] will return "one". You can also reference all
the items in a list using the * syntax:

{"foo": {"bar": [{"name": "one"}, {"name": "two"}]}}

The expression: foo.bar[*].name will return ["one", "two"]. Negative
indexing is also supported (-1 refers to the last element in the list).
Given the data above, the expression foo.bar[-1].name will return ["two"].

The * can also be used for hash types:

{"foo": {"bar": {"name": "one"}, "baz": {"name": "two"}}}

The expression: foo.*.name will return ["one", "two"].

%prep
%setup -q -n %{baseName}-%{version}

%build
python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot} --install-scripts=%{_bindir}
pushd %{buildroot}/%{_bindir}
ln -s jp.py jp
popd

%files
%defattr(-,root,root,-)
%doc LICENSE.txt README.rst
%dir %{python_sitelib}/jmespath
%dir %{python_sitelib}/%{baseName}-%{version}-py%{py_ver}.egg-info
%{_bindir}/jp
%{_bindir}/jp.py
%{python_sitelib}/jmespath/*
%{python_sitelib}/*egg-info/*

%changelog
* Wed Mar 29 2017 jmatejek@suse.com
- properly Requires(postun) for %%postun section
* Wed Mar 29 2017 tbechtold@suse.com
- Only BuildRequire unittest2 for python2
* Thu Mar 16 2017 rjschwei@suse.com
- Switch to single-spec build
- Update to version 0.9.2
  + Fix regression when using ordering comparators on strings (issue 124)
- From 0.9.1
  + Raise LexerError on invalid numbers (issue 98)
  + Add support for custom functions (#100) (issue 100)
  + Fix ZeroDivisionError for built-in function avg() on empty lists (#115)
    (issue 115)
  + Properly handle non numerical ordering operators (#117) (issue 117)
* Mon Aug 15 2016 toddrme2178@gmail.com
- Fix update-alternatives implementation.
* Mon Feb  1 2016 toddrme2178@gmail.com
- Update to version 0.9.0
  * Add support for new lines with tokens in an expression
  * Add support for JEP 9 which introduces "and" expressions, "unary"
    expressions, "not" expressions, and "paren" expressions
  * Fix issue with hardcoded path in ``jp.py`` executable
    (issue 90, issue 88, issue 82)
- Update to version 0.8.0
  * Improve lexing performance (issue 84)
  * Fix parsing error for multiselect lists (issue 86)
  * Fix issue with escaping single quotes in literal strings (issue 85)
  * Add support for providing your own dict cls to support
    ordered dictionaries (issue 94)
  * Add map() function (issue 95)
* Wed Jan 20 2016 rjschwei@suse.com
- Fix build issues for SLE 11
  + More test dependencies required
* Wed Jan 20 2016 rjschwei@suse.com
- Manage the jp executable with update-alternatives now that
  python3-jmespath exists
- spec file improvements
* Wed May 27 2015 rjschwei@suse.com
- Update to version 0.7.1:
  * Rename ``bin/jp`` to ``bin/jp.py``
  * Fix issue with precedence when parsing wildcard
    projections
  * Remove ordereddict and simplejson as py2.6 dependencies.
    These were never actually used in the jmespath code base,
    only in the unit tests.  Unittests requirements are handled
    via requirements26.txt.
* Sun Apr 26 2015 benoit.monin@gmx.fr
- update to version 0.7.0:
  * Add support for JEP-12, raw string literals
  * Support .whl files
- additional changes from version 0.6.2:
  * Implement JEP-10, slice projections
  * Fix bug with filter projection parsing
  * Add to_array function
  * Add merge function
  * Fix error messages for function argument type errors
- point source URL to pypi
* Thu Mar 26 2015 aboe76@gmail.com
- Updated to version 0.6.1
  + No Upstream Changelog
* Sun Jan 18 2015 rschweikert@suse.com
- Update to version 0.5.0
  + No upstream changelog
  + Update in support for fix of bnc#905354
* Thu Oct 23 2014 rschweikert@suse.com
- Update to version 0.4.1
  + No upstream changelog
* Sat Jan 18 2014 rschweikert@suse.com
- Initial build
